import type {
  BaseOption,
  CSelectDate,
  CSelectInfo,
  CSelectLegend,
  CSelectRadio,
  DateOption,
} from '@/types/HomeTypes'
import { CSelectType } from '@/types/HomeTypes'
import { reactive } from 'vue'
import { useDate } from '../useDate'

//  项目分析菜单选择数据
interface ProjctAnalySeleInfo extends CSelectInfo {
  mediaSelect: CSelectRadio
  dateSelect: CSelectDate
  projectSelect: CSelectRadio
}

// 产品分析菜单选择数据
interface ProductAnalySeleInfo extends CSelectInfo {
  mediaSelect: CSelectRadio
  dateSelect: CSelectDate
  dataSource: CSelectRadio
}

// 每个菜单的选择数据格式
interface AnalysisSelectInfo {
  [key: string]: CSelectInfo

  projAnalysis: ProjctAnalySeleInfo
  productAnalysis: ProductAnalySeleInfo
}

// 图例信息格式
interface LegendSelectInfo extends CSelectInfo {
  [key: string]: CSelectLegend
}

// 左侧工具栏选择信息格式
interface LeftToolsSelectInfo extends CSelectInfo {
  dataSource: CSelectRadio
}

// 右侧工具栏选择信息格式
interface RightToolsSelectInfo extends CSelectInfo {
  dataCategory: CSelectRadio
}

// 项目分析图表数据请求格式
interface ProjectChartDataParams {
  [key: string]: any

  project: string
  media: string
  startTime: string
  endTime: string
}

// 产品分析图表数据请求格式
interface ProductChartDataParams {
  [key: string]: any

  media: string
  startTime: string
  endTime: string
  indicator: string
  topType: string
}

// 图表数据请求格式
type ChartDataParams = ProjectChartDataParams | ProductChartDataParams
export type { ProjectChartDataParams, ProductChartDataParams, ChartDataParams }
export type {
  ProjctAnalySeleInfo,
  ProductAnalySeleInfo,
  AnalysisSelectInfo,
  LegendSelectInfo,
  LeftToolsSelectInfo,
  RightToolsSelectInfo,
}

const { createSelectDateOption } = useDate()

export function useAnalysisSelect() {
  // 媒体选择选项
  const mediaSelectOptions: Array<BaseOption> = [
    {
      label: '全部媒体',
      value: 'all',
    },
    {
      label: '媒体1',
      value: 'media1',
    },
  ]

  // 日期选择
  const dateSelectOptions: Array<DateOption> = createSelectDateOption()

  // 项目选择
  const projSelectOptions: Array<BaseOption> = [
    {
      label: '全部项目',
      value: 'ce1',
    },
    {
      label: '测试2',
      value: 'ce2',
    },
    {
      label: '测试3',
      value: 'ce3',
    },
    {
      label: '测试4',
      value: 'ce4',
    },
    {
      label: '测试5',
      value: 'ce5',
    },
    {
      label: '测试6',
      value: 'ce6',
    },
  ]

  // 数据来源选项
  const dataSourceOptions: Array<BaseOption> = [
    {
      label: '消耗',
      value: 'consume',
    },
  ]

  // 左侧工具栏选择框信息
  const leftToolsSelectInfo = reactive<LeftToolsSelectInfo>({
    dataSource: {
      type: CSelectType.Radio,
      name: 'dataSource',
      value: dataSourceOptions[0].value,
      options: dataSourceOptions,
    },
  })

  //  数据分类选项
  const categoryOptions: Array<BaseOption> = [
    {
      label: '汇总',
      value: 'all',
    },
    {
      label: 'Top5产品',
      value: 'top5',
    },
  ]

  //   右侧工具栏选择框信息
  const rightToolsSelectInfo = reactive<RightToolsSelectInfo>({
    dataCategory: {
      type: CSelectType.Radio,
      name: 'dataCategory',
      value: categoryOptions[0].value,
      options: categoryOptions,
    },
  })

  // 项目分析菜单选择栏数据
  const projctAnalySeleInfo = reactive<ProjctAnalySeleInfo>({
    projectSelect: {
      type: CSelectType.Radio,
      name: 'project',
      value: 'all',
      options: projSelectOptions,
    },
    mediaSelect: {
      type: CSelectType.Radio,
      name: 'media',
      value: 'all',
      options: mediaSelectOptions,
    },
    dateSelect: {
      type: CSelectType.Radio,
      name: 'date',
      value: dateSelectOptions[0].value,
      options: dateSelectOptions,
    },
  })

  // 产品分析菜单选择栏数据
  const productAnalySeleInfo = reactive<ProductAnalySeleInfo>({
    mediaSelect: {
      type: CSelectType.Radio,
      name: 'media',
      value: mediaSelectOptions[0].value,
      options: mediaSelectOptions,
    },
    dateSelect: {
      type: CSelectType.Radio,
      name: 'date',
      value: dateSelectOptions[0].value,
      options: dateSelectOptions,
    },
    dataSource: {
      type: CSelectType.Radio,
      name: 'date',
      value: mediaSelectOptions[0].value,
      options: mediaSelectOptions,
    },
  })

  //   计数来源图例的选项
  const countResourceOptions: Array<BaseOption> = [
    {
      label: '消耗',
      value: 'cost',
    },
    {
      label: '展示数',
      value: 'show_count',
    },
  ]

  // 指标图例选项
  const indicatorOptions: Array<BaseOption> = [
    {
      label: '支付数',
      value: 'pay_count',
    },
    {
      label: '转化率',
      value: 'convert_rate',
    },
  ]

  // 图例的选择框信息
  const legendSelectInfo = reactive<{
    [key: string]: LegendSelectInfo
  }>({
    projAnalysis: {
      countResource: {
        type: CSelectType.RadioLegend,
        name: 'countResource',
        value: countResourceOptions[0].value,
        label: countResourceOptions[0].label,
        options: countResourceOptions,
        color: '#197afb',
      },
      indicator: {
        type: CSelectType.RadioLegend,
        name: 'indicator',
        value: indicatorOptions[0].value,
        label: indicatorOptions[0].label,
        options: indicatorOptions,
        color: '#f9b65d',
      },
    },
    productAnalysis: {
      // 产品分析的虽然不展示，但是图表的展示需要用到，所以还是要写
      consumeResource: {
        type: CSelectType.RadioLegend,
        name: 'consumeResource',
        label: categoryOptions[0].label,
        value: categoryOptions[0].value,
        options: categoryOptions,
        color: '#197afb',
      },
    },
  })

  return {
    projctAnalySeleInfo,
    productAnalySeleInfo,
    legendSelectInfo,
    leftToolsSelectInfo,
    rightToolsSelectInfo,
  }
}
