import type { Ref } from 'vue'
import type { BaseMenu } from '@/types/Promotion/Menu'
import router from '@/router'

export function useMenu() {
  /**
   * @description: 设置默认激活的菜单，根据当前路由匹配到对应的菜单
   * @return {*}
   */
  const setRouterDefaultActive = (
    defaultActive: Ref<string>,
    navBarMenuList: BaseMenu[],
  ) => {
    let hasFind = false // 是否找到匹配的菜单
    let matchedRoutedList = router.currentRoute.value.matched // 当前匹配到的路由的数组
    matchedRoutedList.forEach(item => {
      let matchedRouteName = item.name // 把每一个匹配到的路由去再次匹配
      let matchBar = navBarMenuList.find(item => {
        let result = item.name === matchedRouteName
        if (result) return result // 如果匹配到了，则直接返回

        let children = item.children // 没匹配到就去找子菜单
        if (children) {
          return children.some(child => {
            return child.name === matchedRouteName
          })
        }
      })
      if (matchBar) {
        // 有就赋值
        hasFind = true
        defaultActive.value = matchBar.path || ''
      }
    })
    // 没有就赋值为空且报错
    if (!hasFind) {
      defaultActive.value = ''
      throw new Error('当前路由没有匹配到菜单')
    }
  }

  return {
    setRouterDefaultActive,
  }
}
