import type { AxiosResponse } from 'axios'
import type { ResponseInfo } from '@/types/axios'
import { MessageType } from '@/types/axios'

import { ElMessage } from 'element-plus'

import 'element-plus/theme-chalk/el-message.css'
import 'element-plus/theme-chalk/el-message-box.css'

export function useRequest() {
  // let baseURL = 'http://fronttest.ichunhao.cn'
  let baseURL = 'http://127.0.0.1:8113'

  // if (import.meta.env.MODE === 'development') {
  //   baseURL = 'http://server.ichunhao.cn'
  // } else {
  //   baseURL = 'http://service.ichunhao.cn'
  // }

  const loginUrl = 'http://server.ichunhao.cn'
  // TODO 改掉API
  const AllApi = {
    userLogin: `${loginUrl}/user/login`,
    getRefreshToken: `${loginUrl}/user/refreshToken`,
    mockAdTTAcc: `${baseURL}/mock/ad/ttacc`,
    mockAdTTProj: `${baseURL}/mock/ad/ttproj`,
    mockAdTTAd: `${baseURL}/mock/ad/ttad`,
    mockChart: `${baseURL}/mock/home/chart`,
    mockChartProduct: `${baseURL}/mock/home/chartProduct`,

    // mockOverview: `http://192.168.1.220:8080/dashboard/overview`,
    mockOverview: `${baseURL}/mock/home/overview`, // 主页总览数据,
    tags: `${baseURL}/tags`, // 主页总览数据,
  }

  /**
   * @description: 根据返回码给出提示
   * @param data 返回的数据
   * @param  kind 请求类型
   * @param showMsg 是否显示提示
   */
  const analysisResCode = (
    data: AxiosResponse,
    kind = '请求',
    showMsg = true,
  ): Promise<ResponseInfo> => {
    return new Promise((resolve, reject) => {
      let info = JSON.parse(JSON.stringify(data)) as ResponseInfo

      let type: MessageType = MessageType.Success
      let message = info.msg
      let kindText = kind === 'login' ? '登录' : '请求'
      switch (info.code) {
        case 0:
          {
            type = MessageType.Success
            message = `${kindText}成功`
            resolve(info)
          }
          break
        default: {
          type = MessageType.Error
          reject(info.msg)
        }
      }
      if (showMsg) {
        ElMessage({
          type,
          message,
          duration: 1000,
        })
      }
    })
  }

  return {
    AllApi,
    baseURL,
    analysisResCode,
  }
}
