// 总览广告数据类型
interface overviewAdvertisingData {
  name: string // 名称
  title: string // 标题
  value: number // 值
  rate: number // 比例，上升为正，下降为负
}

// 总览广告数据返回格式
interface OverviewRes {
  data: Array<overviewAdvertisingData> // 数据
  media: Array<BaseOption> // 媒体字段
  indicator: Array<BaseOption> // 自定义指标字段
}

// 选择框类型
enum CSelectType {
  Radio = 'radio',
  MultipleTag = 'multipleTag',
  Multiple = 'multiple',
  RadioLegend = 'radioLegend',
  RadioTool = 'radioTool',
}

// 下拉框选项基础类型
interface CSelectOption {
  label: string
  value: any
}

interface BaseOption {}

// 基本下拉框选项类型
interface BaseOption extends CSelectOption {
  value: string
}

/**
 * @description: 日期类型选项值
 * @return {*}
 */
interface DateOptionVal {
  name: string
  startTime: string
  endTime: string
}

// 日期下拉框选项类型
interface DateOption extends CSelectOption {
  value: DateOptionVal
}

// 总览数据选择框格式
interface CSelectItem {
  name: string
  value: any
  type: CSelectType
  tagText?: string // 展示在多选框的文字，保持不变
  color?: string // 颜色，只在legend中存在
  label?: string // 中文名，只在legend中生效
  options: Array<CSelectOption>
}

// 基础选择
interface CSelectRadio extends CSelectItem {
  type: CSelectType.Radio
  options: Array<BaseOption>
  value: string
}

// 日期选择
interface CSelectDate extends CSelectItem {
  type: CSelectType.Radio
  options: Array<DateOption>
  value: DateOptionVal
}

// 多选带
interface CSelectMutiple extends CSelectItem {
  type: CSelectType.Multiple
  options: Array<BaseOption>
  value: string[]
}

// 带有自定义tag的多选
interface CSelectMutipleTag extends CSelectItem {
  type: CSelectType.MultipleTag
  tagText: string // 展示在多选框的文字，保持不变
  options: Array<BaseOption>
  value: string[]
}

// 图例选择框
interface CSelectLegend extends CSelectItem {
  type: CSelectType.RadioLegend
  options: Array<BaseOption>
  color: string
  value: string
  label: string
}

// 选择框信息的基本组织格式
interface CSelectInfo {
  [key: string]: CSelectItem
}

// 所有选项值类型
type AllOptionsVal = string | DateOptionVal | string[]

export { CSelectType }

export type { AllOptionsVal }

export type {
  overviewAdvertisingData,
  CSelectOption,
  BaseOption,
  DateOption,
  CSelectInfo,
  CSelectItem,
  CSelectRadio,
  DateOptionVal,
  CSelectDate,
  CSelectMutiple,
  CSelectMutipleTag,
  CSelectLegend,
  OverviewRes,
}
