import type { AllAdmgeTtFields, AllAdMgeTtTablesData } from './tableData/ttAd'
import type {
  AllAdmgeTencentFields,
  AllAdMgeTencentTablesData,
} from './tableData/tencentAd'
import type {
  AllTtAccMgeFields,
  AllTtAccMgeTablesData,
} from './tableData/ttAcc'
import type {
  AllTencentAccMgeFields,
  AllTencentAccMgeTablesData,
} from './tableData/tencentAcc'

import type { TablePaginationProps } from './pagination'

// 表格查询表单中表单项的类型
enum TableFilterType {
  Search,
  Select,
  Date,
}

// 表格字段的基本信息
interface BaseFieldInfo {
  label: string // 标签
  name: string // 字段名
  state: boolean // 是否展示这个字段
  fixed: boolean // 这个字段是否固定展示
}

// 选择框的选项
interface SelectFilterOptions {
  label: string
  value: any
}

// 筛选条件的基础信息
interface BaseFilterItem {
  type: TableFilterType
  label: string
  name: string
  value: any
  placeholder?: string
}

// 搜索框
interface SearchFilterItem extends BaseFilterItem {
  type: TableFilterType.Search
  options: SelectFilterOptions[]
}

// 选择框
interface SelectFilterItem extends BaseFilterItem {
  type: TableFilterType.Select
  options: SelectFilterOptions[]
}

// 日期选择框
interface DateFilterItem extends BaseFilterItem {
  type: TableFilterType.Date
  startDate: Date
  endDate: Date
}

// 所有表格查询表单中表单项的类型
type TableFilterItem = SearchFilterItem | SelectFilterItem | DateFilterItem

// 所有表格数据的数据类型
type TableData =
  | AllAdMgeTtTablesData
  | AllAdMgeTencentTablesData
  | AllTtAccMgeTablesData
  | AllTencentAccMgeTablesData

// 所有表格的字段
type TableFields =
  | AllAdmgeTtFields
  | AllAdmgeTencentFields
  | AllTtAccMgeFields
  | AllTencentAccMgeFields

// 表格每种字段的格式
// T取值来自所有的表格字段
interface BaseFieldItem<T extends TableFields> {
  label: string // 用于分段的标签名，即一组数据的标题
  name: string // 用于分段的字段名，即一组数据的字段名
  value: string[] // 被选中的字段的值
  children: T[] // 每一组数据中的字段
}

// 查询字段需要的信息格式
interface FilterInfo {
  [key: string]: TableFilterItem
}

// 表格的props
interface TableProps {
  filtersInfo: {
    [key: string]: TableFilterItem
  }
  tableData: Array<TableData>
  // tableFields: Array<TableFields>
  tableFields: Array<BaseFieldItem<TableFields>> // 表格字段信息，分段展示
  sortedTableFields: Array<TableFields> // 排序过后的表格字段，整体的
  fixedFields: Array<string> // 需要固定显示的字段
  remotePagination?: boolean // 是否需要远程分页
  paginationConfig: TablePaginationProps // 分页配置
  schemeList: Array<CustomIndicatorScheme> // 自定义方案列表
  excludeExportFields?: Array<string> // 需要排除导出的字段
  activeMenu: string // 当前选中的菜单
}

// 保存的表格信息格式
interface SaveFields {
  name: string // 这个是文件的标识名，也是这个文件的索引键
  label: string // 这个是用户自定义的文件名
  fields: BaseFieldItem<TableFields>[] // 分组后的字段信息
  tableSortedFields: TableFields[] // 排序过后的表格字段
}

// 保存的自定义方案格式
// 如果没有的话会创建一个键位default的方案
interface SaveCustomIncicatorScheme {
  [key: string]: SaveFields
}

// 读取出来的方案列表信息
interface CustomIndicatorScheme {
  name: string // 方案名
  label: string // 方案标签名，即用户自定义的名称
}

// 每个表格需要的信息格式，包含通用的属性
interface TableInfoItem<
  TData extends TableData, // 数据必须来自所有表格数据类型
  TFields extends BaseFieldItem<TableFields>, // 字段必须来自被basefieldItem包装过得所有表格字段
> {
  data: TData[] // 数据数组
  fields: TFields[] // 字段数组
  tableSortedFields: TableFields[] // 排序过后的表格字段，仅用于展示表格字段
  filters: FilterInfo // 过滤信息
  fixedFields: string[] // 固定字段
}

export { TableFilterType }
export type {
  SelectFilterOptions,
  BaseFilterItem,
  SearchFilterItem,
  SelectFilterItem,
  DateFilterItem,
  TableFilterItem,
  TableProps,
  SaveFields,
  SaveCustomIncicatorScheme,
  CustomIndicatorScheme,
  TableData,
  FilterInfo,
  TableFields,
  TableInfoItem,
  BaseFieldInfo,
  BaseFieldItem,
}
