/**
 * @description: 从本地拿数据
 * @param {string} name locastorage的key
 * @param {string} prop 属性名，不传就返回整个对象
 * @return {string | string[]} 本地信息
 */
const getLocalInfo = (name: string, prop?: string): string | string[] => {
  let info = localStorage.getItem(name)
  let result = ''
  if (info) {
    let jsonInfo = JSON.parse(info)

    if (prop) result = jsonInfo[prop]
    else result = jsonInfo
  }

  return result
}

/**
 * @description: 保存到本地
 * @param {string} name locastorage的key
 * @param {any} value 值
 * @param {string} prop 属性名
 * @return {*}
 */
const saveLocalInfo = (name: string, value: any, prop?: string) => {
  let info = localStorage.getItem(name)
  if (info) {
    let jsonInfo = JSON.parse(info)
    if (prop) jsonInfo[prop] = value
    localStorage.setItem(name, JSON.stringify(jsonInfo))
  } else {
    localStorage.setItem(name, JSON.stringify(value))
  }
}

/**
 * @description: 设置登陆状态
 * @param {boolean} state 登录状态
 * @return {*}
 */
const setLoginState = (state: boolean) => {
  localStorage.setItem('loginState', JSON.stringify(state))
}

/**
 * @description: 获取当前登录状态
 * @return {boolean}
 */
const getLoginState = (): boolean => {
  return JSON.parse(localStorage.getItem('loginState') as string) as boolean
}

/**
 * @description: 设置平台选择下拉框的引导层的显示状态
 * @param {boolean} state 状态
 * @return {*}
 */
const setPfSelectTourShowState = (state: boolean) => {
  localStorage.setItem('pfSelectTourShowState', JSON.stringify(state))
}

/**
 * @description:
 * @param {*} boolean
 * @return {*}
 */
const getPfSelectTourShowState = (): boolean => {
  return JSON.parse(localStorage.getItem('pfSelectTourShowState') as string)
}

export {
  getLocalInfo,
  saveLocalInfo,
  setLoginState,
  getLoginState,
  setPfSelectTourShowState,
  getPfSelectTourShowState
}
